#! /bin/sh

. ../../testenv.sh

synth_analyze alu
clean

echo "Test successful"
